=== modified file 'bzrlib/bzrdir.py'
--- bzrlib/bzrdir.py	2006-03-08 03:52:10 +0000
+++ bzrlib/bzrdir.py	2006-03-08 07:55:41 +0000
@@ -28,6 +28,7 @@
 import bzrlib
 import bzrlib.errors as errors
 from bzrlib.lockable_files import LockableFiles, TransportLock
+from bzrlib.lockdir import LockDir
 from bzrlib.osutils import safe_unicode
 from bzrlib.osutils import (
                             abspath,
@@ -535,9 +536,11 @@
     def __init__(self, _transport, _format):
         """See BzrDir.__init__."""
         super(BzrDirPreSplitOut, self).__init__(_transport, _format)
+        assert self._format._lock_class == TransportLock
+        assert self._format._lock_file_name == 'branch-lock'
         self._control_files = LockableFiles(self.get_branch_transport(None),
-                                            'branch-lock',
-                                            TransportLock)
+                                            self._format._lock_file_name,
+                                            self._format._lock_class)
 
     def clone(self, url, revision_id=None, basis=None, force_new_repo=False):
         """See BzrDir.clone()."""
@@ -828,6 +831,11 @@
     _formats = {}
     """The known formats."""
 
+    _lock_file_name = 'branch-lock'
+
+    # _lock_class must be set in subclasses to the lock type, typ.
+    # TransportLock or LockDir
+
     @classmethod
     def find_format(klass, transport):
         """Return the format registered for URL."""
@@ -876,14 +884,13 @@
         del temp_control
         mutter('created control directory in ' + t.base)
         control = t.clone('.bzr')
-        lock_file = 'branch-lock'
         utf8_files = [('README', 
                        "This is a Bazaar-NG control directory.\n"
                        "Do not change any files in this directory.\n"),
                       ('branch-format', self.get_format_string()),
                       ]
         # NB: no need to escape relative paths that are url safe.
-        control_files = LockableFiles(control, lock_file, TransportLock)
+        control_files = LockableFiles(control, self._lock_file_name, self._lock_class)
         control_files.create_lock()
         control_files.lock_write()
         try:
@@ -950,6 +957,8 @@
     removed in format 5; write support for this format has been removed.
     """
 
+    _lock_class = TransportLock
+
     def get_format_string(self):
         """See BzrDirFormat.get_format_string()."""
         return "Bazaar-NG branch, format 0.0.4\n"
@@ -994,6 +1003,8 @@
        Unhashed stores in the repository.
     """
 
+    _lock_class = TransportLock
+
     def get_format_string(self):
         """See BzrDirFormat.get_format_string()."""
         return "Bazaar-NG branch, format 5\n"
@@ -1039,6 +1050,8 @@
      - Format 6 repositories [always]
     """
 
+    _lock_class = TransportLock
+
     def get_format_string(self):
         """See BzrDirFormat.get_format_string()."""
         return "Bazaar-NG branch, format 6\n"
@@ -1090,6 +1103,8 @@
      - Format 7 repositories [optional]
     """
 
+    _lock_class = LockDir
+
     def get_converter(self, format=None):
         """See BzrDirFormat.get_converter()."""
         if format is None:

=== modified file 'bzrlib/tests/test_bzrdir.py'
--- bzrlib/tests/test_bzrdir.py	2006-03-08 03:53:30 +0000
+++ bzrlib/tests/test_bzrdir.py	2006-03-08 07:55:41 +0000
@@ -1,4 +1,4 @@
-# (C) 2005, 2006 Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 # 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -387,6 +387,12 @@
         self.assertEqual(checkout_base,
                          dir.get_workingtree_transport(workingtree.WorkingTreeFormat3()).base)
 
+    def test_meta1dir_uses_lockdir(self):
+        """Meta1 format uses a LockDir to guard the whole directory, not a file."""
+        dir = bzrdir.BzrDirMetaFormat1().initialize(self.get_url())
+        t = dir.transport
+        self.assertIsDirectory('branch-lock', t)
+
         
 class TestFormat5(TestCaseWithTransport):
     """Tests specific to the version 5 bzrdir format."""

